@@ -1,7 +1,7 @@
 from typing import Dict
 
 MAJOR: int = 1
-MINOR: int = 1
+MINOR: int = 3
 PATCH: int = 0
 SUFFIX: str = ""
 
@@ -9,13 +9,13 @@ NAME: str = "sonyflake-py"
 
 AUTHOR: Dict[str, str] = {
     "name": "hjpotter92",
-    "email": "hjpotter92+pypi@gmail.com",
+    "email": f"{NAME}@pypi.hjpotter92.email",
 }
 MAINTAINER: Dict[str, str] = AUTHOR
 
 __version__: str = f"{MAJOR}.{MINOR}.{PATCH}"
 
 if SUFFIX:
-    __version__ += SUFFIX
+    __version__ += f"-{SUFFIX}"
 
 VERSION = __version__
